@@ -4,8 +4,8 @@ from __future__ import unicode_literals
 
 from django.conf import settings
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
 from django_models_ext import BaseModelMixin
+from django_six import gettext_lazy as _
 
 
 class ShortURL(BaseModelMixin):
