@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
-from django.conf.urls import include, url
+
+from django_six import re_path
+
 from django_short_url import views as surl_views
 
 
@@ -8,5 +10,5 @@ app_name = 'django_short_url'
 
 
 urlpatterns = [
-    url(r'^(?P<surl>\w+)', surl_views.short_url_redirect, name='short_url_redirect'),
+    re_path(r'^(?P<surl>\w+)', surl_views.short_url_redirect, name='short_url_redirect'),
 ]
